#include <u.h>
#include <libc.h>
#include <draw.h>
#include <event.h>

// rough approximation of a REC 601 halfband filter
double coefs[] = { 0.007403, 0.2167, 0.5518, 0.2167, 0.007403 };

void
filter(int pixels, double *sig)
{
	int pos, tap, pix;
	double sum, *tmp;

	if ((tmp = malloc(sizeof(double)*pixels)) == nil)
		sysfatal("No memory");

	for (pix = 0; pix < pixels; pix++){
		sum = 0.0;
		for (tap = 0; tap < nelem(coefs); tap++){
			pos = pix + tap - (nelem(coefs) / 2);
 			pos = (pos < 0)? 0: pos; 
			pos = (pos > (pixels -1))? (pixels -1): pos;
			sum += coefs[tap] * sig[pos];
		}
		tmp[pix] = sum;
	}
	memcpy(sig, tmp, sizeof(double)*pixels);
}


void
usage(void)
{
	fprint(2, "usage: zplate [-e | -7 | -1] [-p h] [-l w]\n");
	fprint(2, "  -e        EBU bars\n");
	fprint(2, "  -7        75%% bars\n");
	fprint(2, "  -1        100%% bars\n");
	fprint(2, "  -l l      image height in lines (720)\n");
	fprint(2, "  -p h      image width in pixles (576)\n");
	exits("usage");
}

void
main(int argc, char *argv[])
{
//	Image *m;
	int size;
	Rectangle r;
	char type, str[16], pixel[4];
	unsigned long outchan = ARGB32;
	unsigned char *buf, *bp;
	double pk, *rb, *gb, *bb;
	int width, bar, pixels, lines, x, y;

	pixels = 720;
	lines = 576;
	type = '1';
	ARGBEGIN {
	case '7':
		type = '7';
		break;
	case '1':
		type = '1';
		break;
	case 'e':
		type = 'e';
		break;
	case 'l':
		lines = atof(EARGF(usage()));
		break;
	case 'p':
		pixels = atof(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND

	r.min = Pt(0, 0);
	r.max = Pt(pixels, lines);
	size = Dx(r)*Dy(r)*sizeof(pixel);
	if((buf = malloc(size)) == nil)
		sysfatal("no memory: %r\n");
	if((rb = malloc(Dx(r)*sizeof(double))) == nil)
		sysfatal("no memory: %r\n");
	if((gb = malloc(Dx(r)*sizeof(double))) == nil)
		sysfatal("no memory: %r\n");
	if((bb = malloc(Dx(r)*sizeof(double))) == nil)
		sysfatal("no memory: %r\n");

	bar = 7;
	width = Dx(r) / 7;
	for(x = 0; x < Dx(r); x++){
		if (x && (x % width) == 0)
			bar--;
		pk = (type == '7' || (type == 'e' && bar != 0))? 0.75: 1.0;
		rb[x] = (bar & 2)? pk :0;
		gb[x] = (bar & 4)? pk :0;
		bb[x] = (bar & 1)? pk :0;
	}

	filter(pixels, rb);
	filter(pixels, gb);
	filter(pixels, bb);

	bp = buf;
	for(x = 0; x < Dx(r); x++){
		*bp++ = bb[x] * 0xff;	// B
		*bp++ = gb[x] * 0xff;	// G
		*bp++ = rb[x] * 0xff;	// R
		*bp++ = 0xff;		// A
	}

	for(y = 1; y < Dy(r); y++)
		memcpy(buf+y*bytesperline(r, chantodepth(outchan)), buf, sizeof(pixel)*Dx(r));

	chantostr(str, outchan);
	fprint(1, "%11s %11d %11d %11d %11d ", str, r.min.x, r.min.y, r.max.x, r.max.y);
	if(write(1, buf, size) != size)
		sysfatal("No write");
}

