#include <u.h>
#include <libc.h>
#include <draw.h>
#include <event.h>

enum {
	Lines = 576,
	Pixels = 720,
	White = 255,
	Black = 0,
	Nstep = 8
};

void
usage(void)
{
	fprint(2, "usage: %s [-p w] [-l h] luma\n", argv0);
	fprint(2, "  luma      luma level of flat field (0.5)\n");
	fprint(2, "  -l h      image height in lines (%d)\n", Lines);
	fprint(2, "  -p w      image width in pixles (%d)\n", Pixels);
	exits("usage");
}

void
main(int argc, char *argv[])
{
	Rectangle r;
	char str[16];
	uchar *buf;
	int size, luma, linelen, pixels, lines;

	lines = Lines;
	pixels = Pixels;
	ARGBEGIN {
	case 'l':
		lines = atoi(EARGF(usage()));
		break;
	case 'p':
		pixels = atoi(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND;

	if(argc == 0)
		usage();
	luma = atof(argv[argc-1]) * White;
	if(luma < 0)
		luma = 0;
	if(luma > White)
		luma = White;

	r.min = Pt(0, 0);
	r.max = Pt(pixels, lines);
	linelen = bytesperline(r, chantodepth(GREY8));
	size = linelen * Dy(r);
	if((buf = mallocz(size, 1)) == nil)
		sysfatal("no memory: %r\n");

	memset(buf, luma, size);

	chantostr(str, GREY8);
	fprint(1, "%11s %11d %11d %11d %11d ", str, r.min.x, r.min.y, r.max.x, r.max.y);
	if(write(1, buf, size) != size)
		sysfatal("write fail");
	exits(0);
}

