#include <u.h>
#include <libc.h>
#include <draw.h>
#include <event.h>

enum {
	Lines = 576,
	Pixels = 720,
	White = 255,
	Black = 0,
	Nstep = 8
};

void
usage(void)
{
	fprint(2, "usage: %s [-p w] [-l h]\n", argv0);
	fprint(2, "  -l h      image height in lines (%d)\n", Lines);
	fprint(2, "  -p w      image width in pixles (%d)\n", Pixels);
	exits("usage");
}

void
main(int argc, char *argv[])
{
	Rectangle r;
	char str[16];
	uchar *buf, *tmp, *bp;
	int size, p, l, step, linelen, pixels, lines;

	lines = Lines;
	pixels = Pixels;
	ARGBEGIN {
	case 'l':
		lines = atof(EARGF(usage()));
		break;
	case 'p':
		pixels = atof(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND;

	r.min = Pt(0, 0);
	r.max = Pt(pixels, lines);
	linelen = bytesperline(r, chantodepth(GREY8));
	size = linelen * Dy(r);
	if((buf = mallocz(size, 1)) == nil)
		sysfatal("no memory: %r\n");
	if((tmp = mallocz(pixels, 1)) == nil)
		sysfatal("no memory: %r\n");

	step = 0;
	for(p = 0; p < pixels; p++){
		if(p % (pixels / Nstep) == 0 && p != 0)
			step++;
		tmp[p] = step * (White / Nstep);
	}

	for(l = 0; l < lines; l++){
		bp = buf + l * linelen;
		memcpy(bp, tmp, pixels);
	}

	chantostr(str, GREY8);
	fprint(1, "%11s %11d %11d %11d %11d ", str, r.min.x, r.min.y, r.max.x, r.max.y);
	if(write(1, buf, size) != size)
		sysfatal("write fail");
	exits(0);
}

