#include <u.h>
#include <libc.h>
#include <draw.h>
#include <event.h>

enum {
	Lines = 576,
	Pixels = 720,
	White = 255,
	Black = 0,
	Boxsz = 48
};

void
usage(void)
{
	fprint(2, "usage: %s [-p w] [-l h]\n", argv0);
	fprint(2, "  -l h      image height in lines (%d)\n", Lines);
	fprint(2, "  -p w      image width in pixles (%d)\n", Pixels);
	exits("usage");
}

int
active(int x)
{
	if(((x-1) % Boxsz) == 0)
		return 1;
	if((x % Boxsz) == 0)
		return 1;
	if(((x+1) % Boxsz) == 0)
		return 1;
	return 0;
}

void
main(int argc, char *argv[])
{
	Rectangle r;
	char str[16];
	uchar *buf, *dotted, *bp;
	int size, p, l, linelen, pixels, lines;

	lines = Lines;
	pixels = Pixels;
	ARGBEGIN {
	case 'l':
		lines = atof(EARGF(usage()));
		break;
	case 'p':
		pixels = atof(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND;

	r.min = Pt(0, 0);
	r.max = Pt(pixels, lines);
	linelen = bytesperline(r, chantodepth(GREY8));
	size = linelen * Dy(r);
	if((buf = mallocz(size, 1)) == nil)
		sysfatal("no memory: %r\n");
	if((dotted = mallocz(pixels, 1)) == nil)
		sysfatal("no memory: %r\n");

	for(p = 0; p < pixels; p++)
		if(active(p))
			dotted[p] = White;

	for(l = 0; l < lines; l++){
		bp = buf + l * linelen;
		if(active(l))
			memset(bp, White, pixels);
		else
			memcpy(bp, dotted, pixels);
	}


	chantostr(str, GREY8);
	fprint(1, "%11s %11d %11d %11d %11d ", str, r.min.x, r.min.y, r.max.x, r.max.y);
	if(write(1, buf, size) != size)
		sysfatal("write fail");
	exits(0);
}

