#include <u.h>
#include <libc.h>
#include <draw.h>
#include <event.h>

enum {
	Lines = 576,
	Pixels = 720,
	White = 255,
	Black = 0
};

void
usage(void)
{
	fprint(2, "usage: zplate [-c a] [-x b] [-y c] [-X d] [-Y e] [-p x] [-l y]\n");
	fprint(2, "  -c a      start phase (0)\n");
	fprint(2, "  -x b      horz phase increment (0.5)\n");
	fprint(2, "  -y c      vert phase increment (0.5)\n");
	fprint(2, "  -X d      rate of change of horz phase increment (0.5)\n");
	fprint(2, "  -Y e      rate of change of vert phase increment (0.5)\n");
	fprint(2, "  -l x      image height in lines (%d)\n", Lines);
	fprint(2, "  -p y      image width in pixles (%d)\n", Pixels);
	exits("usage");
}

void
main(int argc, char *argv[])
{
	char str[16];
	Rectangle r;
	int size, p, l, x, y;
	unsigned char *buf, *bp;
	double pi = 4.0*atan(1.0);
	double a, b, c, d, e, px, py;

	a = 0.0;
	b = 0.5;
	c = 0.5;
	d = 0.5;
	e = 0.5;
	p = Pixels;
	l = Lines;

	ARGBEGIN{
	case 'c':
		a = atof(EARGF(usage()));
		break;
	case 'x':
		b = atof(EARGF(usage()));
		break;
	case 'y':
		c = atof(EARGF(usage()));
		break;
	case 'X':
		d = atof(EARGF(usage()));
		break;
	case 'Y':
		e = atof(EARGF(usage()));
		break;
	case 'l':
		l = atof(EARGF(usage()));
		break;
	case 'p':
		p = atof(EARGF(usage()));
		break;
	default:
		usage();
		break;
	}ARGEND

	a = a * pi;
	b = (b / p) * 2 * pi;
	c = (c / l) * 2 * pi;
	d = (d / p) * 2 * pi;
	e = (e / l) * 2 * pi;

	r.min = Pt(-p/2, -l/2);
	r.max = Pt(p/2, l/2);
	size = Dx(r)*Dy(r);
	if((buf = (unsigned char *)malloc(size)) == nil)
		sysfatal("no memory: %r\n");
	for(y = 0; y < Dy(r); y++){
		py = r.min.y + y;
		bp = buf + y * bytesperline(r, chantodepth(GREY8));
		for(x = 0; x < Dx(r); x++){
			px = r.min.x + x;
			*bp++ = (sin((a)+(b*px)+(c*py)+(d*px*px)+(e*py*py))+1.0) * ((White - Black)/2);
		}
	}


	chantostr(str, GREY8);
	fprint(1, "%11s %11d %11d %11d %11d ", str, r.min.x, r.min.y, r.max.x, r.max.y);
	if(write(1, buf, size) != size)
		sysfatal("write fail");
	exits(0);
}

